Crate citum_resolver_api

Crate citum_resolver_api 

Canonical style resolution interfaces for the Citum citation engine.

This crate provides a lightweight bridge between the schema layer (which defines style models) and the store layer (which implements persistence and network resolution). It minimizes dependencies to facilitate integration by third-party tool authors who don’t need the full store logic.

Re-exports

pub use error::ResolutionError;
pub use error::ResolverError;

Modules

error
Error types and conversion helpers.

Traits

StyleResolver
A resolver that can locate styles and locales.