ResolverError

Enum ResolverError 

#[non_exhaustive]
pub enum ResolverError { Io(Error), InvalidStyle(Cow<'static, str>), StyleNotFound(Cow<'static, str>), LocaleNotFound(Cow<'static, str>), YamlError(String), JsonError(Error), CborError(String), Denied { uri: String, reason: String, }, VersionMismatch { uri: String, required: String, declared: String, }, IntegrityFailure { uri: String, expected: String, actual: String, }, NetworkError { uri: String, reason: String, }, }
Error type for style resolution operations at the store layer.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io(Error)

An underlying I/O error occurred.



InvalidStyle(Cow<'static, str>)

The style content is malformed or invalid for the target version.



StyleNotFound(Cow<'static, str>)

The requested style could not be located.



LocaleNotFound(Cow<'static, str>)

The requested locale could not be located.



YamlError(String)

Failure during YAML deserialization.



JsonError(Error)

Failure during JSON deserialization.



CborError(String)

Failure during CBOR deserialization.



Denied

The URI host or origin is not in the resolver’s allowlist.

Fields

uri: String

The URI that was denied.

reason: String

Reason for the denial.



VersionMismatch

The style’s citum-version is not compatible with the running engine.

Fields

uri: String

URI of the style with the incompatible version.

required: String

Version requirement declared by the style.

declared: String

Version of the running engine.



IntegrityFailure

The content does not match the expected integrity hash.

Fields

uri: String

URI of the content that failed verification.

expected: String

The expected CIDv1 string.

actual: String

The CID computed from the actual content bytes.



NetworkError

Generic network or transport failure.

Fields

uri: String

URI of the failed fetch.

reason: String

Reason for the network failure.